@@ -1,7 +1,7 @@
 /**
  * Utilities for the quality of service module mod_qos.
  *
- * See http://opensource.adnovum.ch/mod_qos/ for further
+ * See http://mod-qos.sourceforge.net/ for further
  * details.
  *
  * Copyright (C) 2007-2016 Pascal Buchbinder
@@ -29,8 +29,8 @@
 /* ----------------------------------
  * version info
  * ---------------------------------- */
-static const char man_version[] = "11.31";
-static const char man_date[] = "July 2016";
+static const char man_version[] = "11.36";
+static const char man_date[] = "November 2016";
 
 /* ----------------------------------
  * definitions
