@@ -3,7 +3,7 @@
  *
  * Log data signing tool to ensure data integrity.
  *
- * See http://opensource.adnovum.ch/mod_qos/ for further
+ * See http://mod-qos.sourceforge.net/ for further
  * details.
  *
  * Copyright (C) 2010-2016 Pascal Buchbinder
@@ -28,7 +28,7 @@
  *
  */
 
-static const char revision[] = "$Id: qssign.c,v 1.44 2016/01/26 16:44:08 pbuchbinder Exp $";
+static const char revision[] = "$Id: qssign.c,v 1.47 2016/10/29 13:07:24 pbuchbinder Exp $";
 
 #include <stdio.h>
 #include <unistd.h>
@@ -111,15 +111,30 @@ static const qos_p_t pattern[] = {
  * @param sec_len Length of the secret
  */
 static void qs_write(char *line, int line_size, const char *sec, int sec_len) {
-  HMAC_CTX ctx;
+#if OPENSSL_VERSION_NUMBER < 0x10100000L
+  HMAC_CTX hmac;
+  HMAC_CTX *hmac_p = &hmac;
+#else
+  HMAC_CTX *hmac_p;
+#endif
   unsigned char data[HMAC_MAX_MD_CBLOCK];
   unsigned int len;
   char *m;
   int data_len;
   sprintf(&line[strlen(line)], " %."SEQDIG"ld", m_nr);
-  HMAC_Init(&ctx, sec, sec_len, m_evp);
-  HMAC_Update(&ctx, (const unsigned char *)line, strlen(line));
-  HMAC_Final(&ctx, data, &len);
+#if OPENSSL_VERSION_NUMBER < 0x10100000L
+  HMAC_CTX_init(hmac_p);
+#else
+  hmac_p = HMAC_CTX_new();
+#endif
+  HMAC_Init_ex(hmac_p, sec, sec_len, m_evp, NULL);
+  HMAC_Update(hmac_p, (const unsigned char *)line, strlen(line));
+  HMAC_Final(hmac_p, data, &len);
+#if OPENSSL_VERSION_NUMBER < 0x10100000L
+  HMAC_CTX_cleanup(hmac_p);
+#else
+  HMAC_CTX_free(hmac_p);
+#endif
   m = calloc(1, apr_base64_encode_len(len) + 1);
   data_len = apr_base64_encode(m, (char *)data, len);
   m[data_len] = '\0';
@@ -414,7 +429,12 @@ static long qs_verify(const char *sec) {
   while(fgets(line, line_size, stdin) != NULL) {
     int valid = 0;
     long ns = 0;
-    HMAC_CTX ctx;
+#if OPENSSL_VERSION_NUMBER < 0x10100000L
+    HMAC_CTX hmac;
+    HMAC_CTX *hmac_p = &hmac;
+#else
+    HMAC_CTX *hmac_p;
+#endif
     unsigned char data[HMAC_MAX_MD_CBLOCK];
     unsigned int len;
     char *m;
@@ -436,9 +456,19 @@ static long qs_verify(const char *sec) {
       sig[0] = '\0';
       sig++;
       /* verify hmac */
-      HMAC_Init(&ctx, sec, sec_len, m_evp);
-      HMAC_Update(&ctx, (const unsigned char *)line, strlen(line));
-      HMAC_Final(&ctx, data, &len);
+#if OPENSSL_VERSION_NUMBER < 0x10100000L
+      HMAC_CTX_init(hmac_p);
+#else
+      hmac_p = HMAC_CTX_new();
+#endif
+      HMAC_Init_ex(hmac_p, sec, sec_len, m_evp, NULL);
+      HMAC_Update(hmac_p, (const unsigned char *)line, strlen(line));
+      HMAC_Final(hmac_p, data, &len);
+#if OPENSSL_VERSION_NUMBER < 0x10100000L
+      HMAC_CTX_cleanup(hmac_p);
+#else
+      HMAC_CTX_free(hmac_p);
+#endif
       m = calloc(1, apr_base64_encode_len(len) + 1);
       data_len = apr_base64_encode(m, (char *)data, len);
       m[data_len] = '\0';
@@ -599,9 +629,9 @@ static void usage(char *cmd, int man) {
     printf(".SH SEE ALSO\n");
     printf("qsexec(1), qsfilter2(1), qsgeo(1), qsgrep(1), qshead(1), qslog(1), qslogger(1), qspng(1), qsrotate(1), qstail(1)\n");
     printf(".SH AUTHOR\n");
-    printf("Pascal Buchbinder, http://opensource.adnovum.ch/mod_qos/\n");
+    printf("Pascal Buchbinder, http://mod-qos.sourceforge.net/\n");
   } else {
-    printf("See http://opensource.adnovum.ch/mod_qos/ for further details.\n");
+    printf("See http://mod-qos.sourceforge.net/ for further details.\n");
   }
   if(man) {
     exit(0);
